/***********************************************************************
 *  rgbDriver.c
 *  gets its marching orders from its 'stdin' stream (e.g. 255 0 80)
 *  interrupt driven, switching the control lines to RGB LED as needed,
 *  utilizing the 'softPwm' library
 *
 *  RonMiller Dec2015,  created for Pi-Zero IOT RGB Color Lamp / Indicator
 *  project at http://www.instructables.com/member/RonM9?show=INSTRUCTABLES
 *
 *  cmd to compile: cc -o rgbDriver rgbDriver.c -lwiringPi -lpthread
 *
 ***********************************************************************/

#include <stdio.h>

#include <wiringPi.h>
#include <softPwm.h>

#define RANGE 127 // value passed to pwmSetRange.
//      using 255 results in flicker when paritial light

#define RED_PIN 1
#define GRN_PIN 2
#define BLU_PIN 3

#define LINE_LEN 64	// only need ~12 for normal data, extras are for #comment lines


  char line[LINE_LEN+1];

int main(int argc, char * argv[])
{
    char *lptr = &line[0];
    int nbytes = LINE_LEN, nread;
    int red,grn,blu;
    int i=0;

    wiringPiSetup();
    // setup for software PWM
    pinMode (RED_PIN, OUTPUT);
    pinMode (GRN_PIN, OUTPUT);
    pinMode (BLU_PIN, OUTPUT);
    // int softPwmCreate (int pin, int initialValue, int pwmRange) ;
    softPwmCreate (RED_PIN, 0, RANGE);
    softPwmCreate (GRN_PIN, 0, RANGE);
    softPwmCreate (BLU_PIN, 0, RANGE);
    //pwmSetClock(clock);       // Default 32 (int)
    //pwmSetMode(PWM_MODE_BAL or PWM_MODE_MS) but we leave it set to default

	printf("\nRGB Worker-Bee ready\n");
	while (1) {
		nread = getline(&lptr, &nbytes, stdin);	// will block while awaiting input
		if (-1 == nread) { 
			printf("\nEOF (or error) incountered.\n");
			return 1;
		}
                if ('#' == line[0]) {
                        // pass comment lines through
                        printf("stdin got this: %s", line);
                } else {
                        sscanf(line, "%d %d %d", &red, &grn, &blu);
                        //printf("r:%d g:%d b:%d\n", red,grn,blu);
			// values are 0-255 so /2 for 0-127 range
                        softPwmWrite(RED_PIN, red/2);
                        softPwmWrite(GRN_PIN, grn/2);
                        softPwmWrite(BLU_PIN, blu/2);
                }
        }

        softPwmWrite(RED_PIN, 0);
        softPwmWrite(GRN_PIN, 0);
        softPwmWrite(BLU_PIN, 0);

    return 0;
}
