/**********************************************************************
 *  rgb_main.js
 *  event driven nodeJS web service using 'express' and utilizing socket IO
 *
 *  RonMiller Dec2015,  created for Pi-Zero IOT RGB Color Lamp / Indicator
 *  project at http://www.instructables.com/member/RonM9?show=INSTRUCTABLES
 *
 *  cmd to run: sudo node rgb_main.js &
 *  then, in a browser goto http://localhost:8080/
 *
 **********************************************************************/


var express = require('express');
app = express();
server = require('http').createServer(app);
io = require('socket.io').listen(server);

server.listen(8080);
app.use(express.static('public'));

// initial brightness
var r=5,g=5,b=5;

const child_process = require('child_process');
const child = child_process.spawn(
              './rgbDriver', [], { stdio: ['pipe', process.stdout, process.stderr]});

child.stdin.write(r+' '+g+' '+b+"\n");  // set initial brightness

io.sockets.on('connection',
  function (socket) {
        socket.on('rgb', function (data) {
                //brightness = data.red;
                r = data.red; g = data.grn; b = data.blu;
                //console.log('RGB values: '+r+' '+g+' '+b);
                child.stdin.write(r+' '+g+' '+b+"\n");  // tell child of new settings

                // Broadcast the new RGB values to socket listeners
                socket.broadcast.emit('rgb', {red: data.red, grn: data.grn, blu: data.blu});
        });

        // Send out initial RGB values
        socket.emit('rgb', {red: r, grn: g, blu: b});
  });

console.log("# RGB iot running");
